@@ -1,6 +1,6 @@
 package EntityModel::Support::Perl::Base;
-BEGIN {
-  $EntityModel::Support::Perl::Base::VERSION = '0.013';
+{
+  $EntityModel::Support::Perl::Base::VERSION = '0.014';
 }
 use EntityModel::Class {
 };
@@ -11,7 +11,7 @@ EntityModel::Support::Perl::Base - base class for entity instances
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -397,6 +397,22 @@ sub commit {
 	return $self;
 }
 
+sub done {
+	my $self = shift;
+	return $self if $self->{failure};
+	my $code = shift;
+	$code->($self);
+	return $self;
+}
+
+sub fail {
+	my $self = shift;
+	return $self unless $self->{failure};
+	my $code = shift;
+	$code->($self, $self->{failure});
+	return $self;
+}
+
 sub then {
 	my $self = shift;
 	$self->commit;
